@@ -40,7 +40,11 @@ Use as follows:
     
     $geocoder_multi->add_geocoder( $place_finder_options );
     
-    my $location = $geocoder_multi->geocode( { location => '82 Clerkenwell Road, London, EC1M 5RF' } );
+    my $location = $geocoder_multi->geocode( 
+        {
+            location => '82 Clerkenwell Road, London, EC1M 5RF'
+        }
+    );
 
 =head1 USAGE POLICY
 
@@ -90,7 +94,7 @@ sub geocode {
 
     $response->set_response_code($http_response->code());
 
-    return( $response );
+    return $response;
 };
 
 =head2 get_name
@@ -107,9 +111,12 @@ Dan Horgan, C<< <cpan at lokku.com> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-geo-coder-multiple-placefinder at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Geo-Coder-Many-PlaceFinder>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to 
+C<bug-geo-coder-multiple-placefinder at rt.cpan.org>, or through the web
+interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Geo-Coder-Many-PlaceFinder>.
+I will be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
 
 
 
@@ -143,12 +150,6 @@ L<http://search.cpan.org/dist/Geo-Coder-Many-PlaceFinder/>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-This module is based on the Geo::Coder::Many::* modules provided with Geo::Coder::Many.
-It is, of course, useless without Geo::Coder::Many and Geo::Coder::PlaceFinder.
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2010 Lokku Ltd.
